@@ -8,10 +8,7 @@ use Scalar::Util 1.16 qw(weaken looks_like_number);
 # Declare ourself as a subclass
 use base 'Math::Random::MT::Auto';
 
-our $VERSION = '4.07.00';
-
-# Set ID() as alias for refaddr() function
-*ID = \&Scalar::Util::refaddr;
+our $VERSION = '4.08.00';
 
 
 ### Package Global Variables ###
@@ -19,7 +16,7 @@ our $VERSION = '4.07.00';
 # Object attribute hashes used by inside-out object model
 #
 # Data stored in these hashes is keyed to the object by a unique ID that is
-# obtained using ID($obj).
+# stored in the object's scalar reference.
 
 # Range information for our objects
 my %TYPE;       # Type of range:  INTEGER or DOUBLE
@@ -71,20 +68,6 @@ sub new
         Carp::croak('Missing parameter: HIGH');
     }
 
-    # Obtain new object from parent class
-    my $self = __PACKAGE__->SUPER::new(%parent_args);
-
-    # Rebless object into specified class
-    # 'bless()' cannot be used because the object
-    #   is set to 'readonly' by ->new()
-    $self->_rebless($class);
-
-    # The object's ID (refaddr()) is used as a hash key for the object
-    my $id = ID($self);
-
-    # Save weakened reference to object for thread cloning
-    weaken($REGISTRY{$id} = $self);
-
     # Default 'TYPE' to 'INTEGER' if 'LOW' and 'HIGH' are both integers
     if (! exists($my_args{'TYPE'})) {
         my $lo = $my_args{'LOW'};
@@ -94,6 +77,17 @@ sub new
                          : 'DOUBLE';
     }
 
+    # Obtain new object from parent class
+    my $self = __PACKAGE__->SUPER::new(%parent_args);
+
+    # Rebless object into specified class
+    # 'bless()' cannot be used because the object
+    #   is set to 'readonly' by ->new()
+    $self->_rebless($class);
+
+    # Save weakened reference to object for thread cloning
+    weaken($REGISTRY{$$self} = $self);
+
     # Perform subclass initialization
     $self->set_range_type($my_args{'TYPE'});
     $self->set_range($my_args{'LOW'}, $my_args{'HIGH'});
@@ -111,16 +105,12 @@ sub clone
     # Call parent class 'clone' method
     my $self = $parent->SUPER::clone();
 
-    # The object's ID (refaddr()) is used as a hash key for the object
-    my $id = ID($self);
-
     # Save weakened reference to object for thread cloning
-    weaken($REGISTRY{$id} = $self);
+    weaken($REGISTRY{$$self} = $self);
 
     # Perform subclass initialization using parent's properties
-    my $parent_id = ID($parent);
-    $self->set_range_type($TYPE{$parent_id});
-    $self->set_range($LOW{$parent_id}, $HIGH{$parent_id});
+    $self->set_range_type($parent->get_range_type());
+    $self->set_range($parent->get_range());
 
     # Done - return object
     return ($self);
@@ -138,14 +128,15 @@ sub set_range_type
         Carp::croak('Arg to ->set_range_type() must be \'INTEGER\' or \'DOUBLE\'');
     }
 
-    $TYPE{ID($self)} = ($type =~ /^I/i) ? 'INTEGER' : 'DOUBLE';
+    $TYPE{$$self} = ($type =~ /^I/i) ? 'INTEGER' : 'DOUBLE';
 }
 
 
 # Return current range type
 sub get_range_type
 {
-    return ($TYPE{ID(shift)});
+    my $self = shift;
+    return ($TYPE{$$self});
 }
 
 
@@ -153,7 +144,6 @@ sub get_range_type
 sub set_range
 {
     my $self = shift;
-    my $id = ID($self);
 
     # Check for arguments
     my ($lo, $hi) = @_;
@@ -162,7 +152,7 @@ sub set_range
     }
 
     # Ensure arguments are of the proper type
-    if ($TYPE{$id} eq 'INTEGER') {
+    if ($TYPE{$$self} eq 'INTEGER') {
         $lo = int($lo);
         $hi = int($hi);
     } else {
@@ -179,12 +169,12 @@ sub set_range
     }
 
     # Set range parameters
-    $LOW{$id}  = $lo;
-    $HIGH{$id} = $hi;
-    if ($TYPE{$id} eq 'INTEGER') {
-        $RANGE{$id} = ($HIGH{$id} - $LOW{$id}) + 1;
+    $LOW{$$self}  = $lo;
+    $HIGH{$$self} = $hi;
+    if ($TYPE{$$self} eq 'INTEGER') {
+        $RANGE{$$self} = ($HIGH{$$self} - $LOW{$$self}) + 1;
     } else {
-        $RANGE{$id} = $HIGH{$id} - $LOW{$id};
+        $RANGE{$$self} = $HIGH{$$self} - $LOW{$$self};
     }
 }
 
@@ -193,8 +183,7 @@ sub set_range
 sub get_range
 {
     my $self = shift;
-    my $id = ID($self);
-    return ($LOW{$id}, $HIGH{$id});
+    return ($LOW{$$self}, $HIGH{$$self});
 }
 
 
@@ -203,14 +192,13 @@ sub get_range
 sub rrand
 {
     my $self = $_[0];
-    my $id = ID($self);
 
-    if ($TYPE{$id} eq 'INTEGER') {
+    if ($TYPE{$$self} eq 'INTEGER') {
         # Integer random number range [LOW, HIGH]
-        return (($self->irand() % $RANGE{$id}) + $LOW{$id});
+        return (($self->irand() % $RANGE{$$self}) + $LOW{$$self});
     } else {
         # Floating-point random number range [LOW, HIGH)
-        return ($self->rand($RANGE{$id}) + $LOW{$id});
+        return ($self->rand($RANGE{$$self}) + $LOW{$$self});
     }
 }
 
@@ -218,19 +206,18 @@ sub rrand
 # Object Destructor
 sub DESTROY {
     my $self = $_[0];
-    my $id = ID($self);
 
     # Call parent's destructor first
     $self->SUPER::DESTROY();
 
     # Delete all subclass data used for the object
-    delete($TYPE{$id});
-    delete($LOW{$id});
-    delete($HIGH{$id});
-    delete($RANGE{$id});
+    delete($TYPE{$$self});
+    delete($LOW{$$self});
+    delete($HIGH{$$self});
+    delete($RANGE{$$self});
 
     # Remove object from thread cloning registry
-    delete($REGISTRY{$id});
+    delete($REGISTRY{$$self});
 }
 
 
@@ -246,17 +233,14 @@ sub CLONE
             # Get cloned object associated with old ID
             my $obj = delete($REGISTRY{$old_id});
 
-            # New ID for referencing the cloned object
-            my $new_id = ID($obj);
-
             # Relocate object data
-            $TYPE{$new_id}  = delete($TYPE{$old_id});
-            $LOW{$new_id}   = delete($LOW{$old_id});
-            $HIGH{$new_id}  = delete($HIGH{$old_id});
-            $RANGE{$new_id} = delete($RANGE{$old_id});
+            $TYPE{$$obj}  = delete($TYPE{$old_id});
+            $LOW{$$obj}   = delete($LOW{$old_id});
+            $HIGH{$$obj}  = delete($HIGH{$old_id});
+            $RANGE{$$obj} = delete($RANGE{$old_id});
 
             # Save weak reference to this cloned object
-            weaken($REGISTRY{$new_id} = $obj);
+            weaken($REGISTRY{$$obj} = $obj);
         }
     }
 }
